# Canvs Toolbox Package

### Import Statement
from canvs_toolbox import explore as ex

### Date Formatting
"MM/DD/YYYY" 

## Canvs TV Tools
- ex.tv_twitter_daily(api_key, data_mode, start_date, end_date)
- ex.tv_airings_backfill(api_key, data_mode, start_date, end_date)
- ex.tv_facebook_backfill(api_key, data_mode, start_date, end_date)

## Canvs Watch Tools
- ex.watch_post_backfill(api_key, data_mode, start_date, end_date)
- ex.watch_series_backfill(api_key, data_mode, start_date, end_date)


